
//COVID ANALYSIS: DATA CLEANING FILE

/*
This file contains all cleaning for the main analysis for WD paper
*/

clear all
set varabbrev off
set more off, permanent
set scheme plotplain

if c(username)=="Rocco Zizzamia" {
 cd "C:\Users\Rocco Zizzamia\Dropbox\Policy_response_corona\"
}
if c(username)=="ihsaa" {
	cd "C:\Users\ihsaa\Dropbox\Policy_response_corona\"
}
if c(username)=="joshb" {
 cd "C:\Users\joshb\Dropbox\projects\Policy_response_corona\"
}

global wd "WDpaper_analysis\"



****************************************************************
*DATA SETUP 
****************************************************************


use "NIDSw5_setup\Crossection_w5", clear
numlabel, add

rename sample sample_w5
rename w5_* *

count if wgt == 0
assert r(N) == 1
drop if wgt == 0

replace best_age_yrs = . if best_age_yrs < 0

gen fwgt = round(wgt)

*Employment types
*** Type of employment
	recode em1 em2 ems emsoth emc emp emh (-9/-2=.) (1=1) (2=0)
	gen empltype=.
	replace empltype=1 if em1==1 & empltype==.
	replace empltype=2 if ems==1 & empltype==.
	replace empltype=3 if emc==1 & empltype==.
	replace empltype=4 if emp==1 & empltype==.
	replace empltype=3 if emh==1 & empltype==.  // Note: help others is small group (<2%) --> group together with casual
	lab def empltype 1 "Employee" 2 "Self-employed" 3 "Casual/help others" 4 "Subsistence"
	lab val empltype empltype
	lab var empltype "Type of employment"
	tab empltype, gen(empltype)


	count if mi(cwag) & !mi(help)
	
	* just make sure this help variable really isn't going to bring in outliers etc
	assert r(N) < 50
	assert inrange(help, 45, 4000) if !mi(help)	

	replace cwag = help if mi(cwag) & !mi(help)

*** Employment characteristics
	recode em1contr (1=1 "Yes") (2=0 "No") (-9/-2=.), gen(written)	
	lab var written "Written employment agreement"
	recode em1dedmed (1=1 "Yes") (2=0 "No") (-9/-2=.), gen(dedmed)	
	lab var dedmed "Medical aid deduction from salary"
	recode em1dedpen (1=1 "Yes") (2=0 "No") (-9/-2=.), gen(dedpen)	
	lab var dedpen "Pension/Provident fund deduction from salary"
	recode emstax (1=1) (2=0) (-9/-2=.), gen(bsnsstax)
	lab var bsnsstax "Registration of business for income tax &/or VAT"
	
	recode em1deduif (1=1 "Yes") (2=0 "No") (-9/-2=.), gen(cleanuif)
	lab var cleanuif "UIF deduction from salary"
	
*** Employment status = inactive unempl_broad unempl_strict employed
	ren empl_stat emplstat
	recode emplstat (-9/-2=.)
	tab emplstat, gen(emplstat) // Note: emplstat=emplyed if w1_a_em1==1 | w1_a_ems==1 | w1_a_emc==1 | w1_a_emp==1 | w1_a_emh==1	
	
*** Area
	assert inlist(geo2001,1,2,3,4) 		// replace geo2001=. if geo2001<0
	assert inlist(geo2011,1,2,3) 		// replace geo2011=. if geo2011<0
	tab geo2011, gen (area)

	
*** Gender
		drop gen
		g gen = best_gen
		replace gen =. if gen < 0
	

//Inflating from March 2017 to Feb 2020
scalar base=115.2 
gen deflator=.

replace deflator=base/100.6 if h_intrv_m==1 & h_intrv_y==2017
replace deflator=base/101.7 if h_intrv_m==2 & h_intrv_y==2017
replace deflator=base/102.3 if h_intrv_m==3 & h_intrv_y==2017
replace deflator=base/102.4 if h_intrv_m==4 & h_intrv_y==2017
replace deflator=base/102.7 if h_intrv_m==5 & h_intrv_y==2017
replace deflator=base/102.9 if h_intrv_m==6 & h_intrv_y==2017
replace deflator=base/103.2 if h_intrv_m==7 & h_intrv_y==2017
replace deflator=base/103.3 if h_intrv_m==8 & h_intrv_y==2017
replace deflator=base/103.8 if h_intrv_m==9 & h_intrv_y==2017
replace deflator=base/104.1 if h_intrv_m==10 & h_intrv_y==2017
replace deflator=base/104.2 if h_intrv_m==11 & h_intrv_y==2017
replace deflator=base/104.7 if h_intrv_m==12 & h_intrv_y==2017

replace deflator=base/103 if h_intrv_m==. & h_outcome==1

lab var deflator "Wave 5 deflator"
assert !mi(deflator)

foreach var in hhincome expenditure fwag hhgovt incdis_v  incchld_v incfos_v inccare_v incaid_v incgovpen_v fwag cwag swag hhwage hhremitt hhinvest hhother hhagric {   
	replace `var' = `var'*deflator
}   




****************************************************************
*INTERVENTION GROUPS
****************************************************************

//Define informal employment
*Formal employment 
gen formal=.

replace formal=1 if empltype==1 & (written==1 | dedmed==1 | dedpen==1 | cleanuif==1)	

assert emplstat == 3 if empltype==1		
assert quest_typ != 3 if empltype==1	
replace formal=0 if empltype==1 & formal != 1
replace formal=. if formal == 0 & written==. & dedmed==. & dedpen==. & cleanuif==.		

replace formal=1 if empltype==2 & bsnsstax==1
replace formal=0 if empltype==2 & bsnsstax==0
replace formal=0 if empltype==3 | empltype==4
lab var formal "Formal employment"	



*Informal employment	
g informal= formal==0 if formal!=.


*Formal and informal worker households
foreach var in formal informal {
	bys hhid: egen temp= max(`var') if `var'!=.
	bys hhid: egen hh`var'= mean(temp)
	replace hh`var'= 0 if hh`var'==.
	assert hh`var'!=.
	drop temp
}


//Define othergrant (not csg or pension)
foreach var in incaid incdis inccare incfos incgovpen incchld {
	replace `var'= (`var'==1)
	assert !mi(`var')
}
g othergrant= (incaid + incdis + inccare + incfos)
assert othergrant!=.




//COG

*identifying those recieving grants
gen grant = 0 if othergrant==0 & incgovpen==0 & incchld==0
replace grant = 1 if othergrant!=0 | incgovpen ==1 | incchld==1
assert grant!=.
bys hhid: egen hhgrant= max(grant)


*Define cog recipients
gen cog = 0 
replace cog = 1 if grant==0 & formal!=1 & em1deduif!= 1 & (best_age_yrs>=18 & best_age_yrs<60 & best_age_yrs!=.)
bys hhid: egen hhcog= max(cog)




//CHILD GRANTS VARS 

*1 obs seems miscoded as no, another as yes 
gen csg= incchld==1
replace csg= 1 if incchld_v!=. & incchld_v>0

assert !mi(csg)
bys hhid: egen hhcsg= max(csg)
assert !mi(hhcsg)	


g csg_income= incchld_v if incchld_v>=0 
bys hhid: egen hhcsg_income = total(csg_income)		
assert !mi(hhcsg_income)
replace csg_income = 0 if mi(csg_income)	

foreach var in hhcsg csg {					
	g `var'_children= 1 if inrange(`var'_income, 0, 630)
	replace `var'_children= 2 if inrange(`var'_income, 630, 1050)
	replace `var'_children= 3 if inrange(`var'_income, 1050, 1470)
	replace `var'_children= 4 if inrange(`var'_income, 1470, 1890)
	replace `var'_children= 5 if inrange(`var'_income, 1890, 2310)
	replace `var'_children= 6 if `var'_income>2310 & `var'_income!=.
	replace `var'_children= 0 if `var'_income==0
	assert !mi(`var'_children)
}


//PENSION GRANTS 
*https://www.gov.za/services/social-benefits-retirement-and-old-age/old-age-pension

gen oap= incgovpen==1
	assert (incgovpen_v>0 & !mi(incgovpen_v)) == 0 if oap == 0
bys hhid: egen hhoap= max(oap)
assert !mi(hhoap)



//define complementary packages: 
*CSG OR COG
g hhcsgcog= (hhcsg==1 | hhcog==1)

*OAP or COG 
g hhoapcog= (hhoap==1 | hhcog==1)






//Other packages

*BIG
g big= inrange(best_age_yrs, 18,59)

*Disability
	assert (incdis_v>0 & !mi(incdis_v)) == 0 if incdis == 0
bys hhid: egen hhdisab= max(incdis)
assert !mi(hhdisab)


****************************************************************
*HOUSEHOLD and HOUSEHOLD MEMBER VARS
****************************************************************

//Add up number of recipients of each grant by HH

foreach var in cog oap csg othergrant informal big {
	bys hhid: egen hhnum_`var'= total(`var')
	assert hhnum_`var'!=.
}


//Totwage
cap drop totwage
egen totwage= rsum(fwag cwag swag)
assert totwage == 0 if emplstat !=3 // replace totwage =0 if emplstat !=3
	

	assert mi(fwag) & mi(cwag) & mi(swag) if emplstat ==3 & totwage ==0
replace totwage =. if emplstat ==3 & totwage ==0



//For formal and informal
foreach var in formal informal {
	bys hhid: egen temp`var'= total(totwage) if `var'==1
	bys hhid: egen hh`var'_income= min(temp`var')
	replace hh`var'_income=0 if hh`var'_income==.
	assert hh`var'_income!=.
}
cap drop temp*


//Define subgroups of informal worker HHs: formal, noformal&grant, noformal&nogrant
g hhinfgrp= 1 if hhinformal==1 & hhformal==1 
replace hhinfgrp= 2 if hhinformal==1 & hhformal==0 & hhgrant==1
replace hhinfgrp= 3 if hhinformal==1 & hhformal==0 & hhgrant==0
lab def hhinfgrp 1 "Formal co-resident" 2 "Grant & no formal co-resident" 3 "No grant & no formal co-resident"
lab val hhinfgrp hhinfgrp 


//HH Decile vars
gen hhincomepc= hhincome / hhsizer
xtile hhincomepc_decile = hhincomepc [aw=wgt], nq(10)


//Remittance?
replace hhremitt=0 if hhremitt==.
g hhanyremit= (hhremitt>0)
assert hhanyremit!=.


//Remittances sending and receiving consistent (note that proxies & children do not answer, but fine for hhlevel where there are *very* few missing)
foreach var in cr cg {
	recode `var' (2 = 0) (-3 = .), gen(ind`var')
	egen hh`var' = max(ind`var'), by(hhid)
} 

rename (indcr hhcr indcg hhcg) (indremitrec hhremitrec indremitsend hhremitsend)

// Dependency ratio

* some misc income sources (regular incomes from pg 50 user manual)
local sumlist
foreach var in ppen prof othe help uif comp indi rnt {
	assert `var'>=0
	gen ind`var' = (`var' > 0 & `var' != .)
	local sumlist `sumlist' ind`var'
}
di "`sumlist'"
egen miscinc = rowmax(`sumlist')

* earner from totwage
gen earner = (totwage > 0 & totwage != .)

* individual inc sources from earning, misc and grants
egen indinc = rowmax(grant earner miscinc)
assert indinc == 1 | indinc == 0

* dep ratio (note that this is a weird and non-standard dependency ratio but seems to make more sense in our context)
bys hhid: egen hhincnum = total(indinc)
gen hhdep = hhsizer - hhincnum
gen depratio = hhdep/hhincnum
	replace depratio = hhdep if hhincnum == 0	


* age dependency ratio (the standard one but for each household)
gen primeage = inrange(best_age_yrs, 15,64)
bys hhid: egen primtot = total(primeage)
gen youngold = hhsizer - primtot
assert !mi(youngold) & !mi(primtot)
replace primtot = 1 if primtot == 0
gen agedepratio = youngold/primtot

	
	
* clean up
drop `sumlist' miscinc earner indinc hhincnum hhdep primeage primtot youngold 


// Age categories

* individual
recode best_age_yrs (0/17=1 "0-17")(18/35=2 "18-35")(36/45=3 "36-45")(46/59=4 "46-59")(60/.=5 "60+"), gen(age_cat)
tab age_cat, gen(agecat)
* hhold
forval i = 1/5 {
	bys hhid: egen hhagecat`i' = mean(agecat`i')
}


// Informal sector (infsec) vs informal worker (infwrk)

* keep the missings/non-missing structure we have in original var
g infsec = informal					
replace infsec = 0 if informal == 1

* informal sector if self-employed and no tax (simple)
assert ems == 1 if !mi(bsnsstax)
replace infsec = 1 if informal == 1 & bsnsstax == 0

* informal work: informal but not inf self-employed 
g infwrk = informal 
replace infwrk = 0 if infsec == 1

* fix the above issue where we have main work AND self-employed and informal==1. just drop from sample by setting to missing. very few affected: only 20 individuals (40k weighted)
replace infwrk = . if informal == 1 & em1 == 1 & ems == 1
replace infsec = . if informal == 1 & em1 == 1 & ems == 1

* check mutual exclusivity and nesting within informal 
assert infwrk == 0 if infsec == 1
assert infsec == 0 if infwrk == 1
assert informal == 1 if infsec == 1
assert informal == 1 if infwrk == 1
assert infsec == . if informal == .
assert infwrk == . if informal == . 

* Informal sector and informal worker households
foreach var in infwrk infsec {
	bys hhid: egen temp= max(`var') if `var'!=.
	bys hhid: egen hh`var'= mean(temp)
	replace hh`var'= 0 if hh`var'==.
	assert hh`var'!=.
	drop temp
}

* Informal sector and informal worker household income
foreach var in infwrk infsec {
	bys hhid: egen temp`var'= total(totwage) if `var'==1
	bys hhid: egen hh`var'_income= min(temp`var')
	replace hh`var'_income=0 if hh`var'_income==.
	assert hh`var'_income!=.
}
cap drop temp*

****************************************************************
*WRAP UP
****************************************************************


//EQUIVALENCE SCALE
gen adult_14 = 1 if best_age_yrs >13 & best_age_yrs !=.
gen child_14 = 1 if best_age_yrs <=13 & best_age_yrs >=0
bysort hhid: egen tot_adult_14 = total(adult_14)
bysort hhid: egen tot_child_14 = total(child_14)


count if tot_adult_14==0
assert r(N) < 5
drop if tot_adult_14==0
assert tot_adult_14 > 0

*Denominators for Original OECD. First adult counted as "1" adult, subsequent adults counted as "0.5" or "0.7" adult equivalents

gen hhsizerequiv = 1+(.7*(tot_adult_14-1))+(.5*(tot_child_14))

gen hhincomeequiv= hhincome / hhsizerequiv
xtile hhincomeequiv_decile = hhincomeequiv [aw=wgt], nq(10)



//Schoolchildren
g schoolmeal= inrange(best_age_yrs, 7,18) & hhincomepc_decile<=6
bys hhid: egen schoolchildren= total(schoolmeal)
assert schoolchildren!=.


//SA ID
*see: tab quest_typ edsaid [fw=fwgt], mi
*All children <15 and proxy missing, about 2.5m adults missing and 34.5m adults non-missing
*compare to "brncc"
g sa_id= (edsaid==1) if edsaid!=.

//MISC
g all= 1
egen hhtag= tag(hhid)
ren area2 urban
g female= gen==2 if gen!=.

keep pid all wgt fwgt hhid hhtag female urban hhsizer* hhincome* *formal* *csg* *grant* *oap* *cog* *big totwage emplstat best_age_yrs edsaid incdis hhdisab incfos  inccare  incaid  hhgovt hhgrant *occ_isco_c *prod_c emssect emsothsect  emcsect em1pay em1hrs brncc expenditure school* quest_typ emplstat hhanyremit sa_id hhinfgrp empltype hhgovt hhremitt hhinvest hhwage hhother hhagric ///
indremitrec hhremitrec indremitsend hhremitsend depratio agedepratio age_cat infwrk infsec hhinfwrk hhinfsec hhinfwrk_income hhinfsec_income agecat* hhagecat*

save "${wd}temp.dta", replace


****************************************************************
// Create dataset without "problem" proxy households, ie households with an employed proxy respondent (whose formal/informal status we can't tell)
****************************************************************

preserve

* identify individuals and hholds affected
gen proxyprob = emplstat==3 & quest_typ==3
bys hhid: egen hh_proxyprob = max(proxyprob)

* some summary stats
tab proxyprob [fw=fwgt], m
tab hh_proxyprob if hhtag == 1 [fw=fwgt], m
tab hh_proxyprob [fw=fwgt], m

* drop them
drop if hh_proxyprob == 1
drop proxyprob hh_proxyprob

	// nopp = no proxy problem
save "${wd}temp_nopp.dta", replace

restore





****************************************************************
* OPTIM DATASET FOR R
****************************************************************

/*
*Set up for optim code
use "${wd}temp.dta", clear 
g cog_dummy= cog
keep hhinformal_income hhincome hhsizer fwgt hhcsg_children csg_children cog_dummy hhnum_cog all hhinformal hhsizerequiv hhtag
saveold "${wd}povoptim.dta", replace version(12)
*/




****************************************************************
// END OF CLEAN
****************************************************************

