
//COVID ANALYSIS: MAIN DATA ANALYSIS FILE

/*
THIS FILE CONTAINS
1. TABLES
2. VENN DIAGRAM REACH BAR GRAPHS
3. INCOME CHANGE LINE GRAPHS
4. POVERTY GRAPHS
5. INCOME SOURCE BY DECILE

*/

clear all
set varabbrev off
set more off, permanent
set scheme plotplain	

if c(username)=="Rocco Zizzamia" {
 cd "C:\Users\Rocco Zizzamia\Dropbox\Policy_response_corona\"
}
if c(username)=="ihsaa" {
	cd "C:\Users\ihsaa\Dropbox\Policy_response_corona\"
}
if c(username)=="joshb" {
 cd "C:\Users\joshb\Dropbox\projects\Policy_response_corona\"
}

global wd "WDpaper_analysis\"
global figout "${wd}rawfigs\"



****************************************************************
* PRELIMINARIES
****************************************************************

//Removing problem-proxy results?	
// pspec (proxy specification) will be "" unless you turn removeproxy to "yes", in which case data in and graphs out will be suffixed with "_nopp" (no problem proxy)

local removeproxy "no"

if "`removeproxy'" == "yes" global pspec "_nopp"
else global pspec ""



//Program to carefully assign zero incomes when negative after shock
* incvar is the income variable to check, limit is the max number of replacements we allow before an error is thrown
cap program drop assignzero
program define assignzero
	syntax, incvar(varname) limit(integer)
	qui count if `incvar' < 0
	if r(N) > `limit' {
		di "{err}more than `limit' negative values in `incvar'"
		exit 498
	}
	else {
		replace `incvar' = 0 if `incvar' < 0
	}
end


//CALCULATE AMOUNT PER GRANT
/*This sections stores as global the top up to each grant corresponding
to a fixed budget. Here budget is R8bn (6months of 8bn is about R50bn)
*/


global budget= 8e9
use "${wd}temp${pspec}.dta", clear


*amount increase per intervention for fixed budget
total hhcsg_children if hhtag==1 [fw=fwgt]
global amtcsg= round($budget /r(table)[1,1])
global amtcsg2= $amtcsg /2

total oap [fw=fwgt]
global amtoap= round($budget /r(table)[1,1])
global amtoap2= $amtoap /2

total cog [fw=fwgt]
global amtcog= round($budget /r(table)[1,1])
global amtcog2= $amtcog /2

di "$amtcsg " " $amtoap " " $amtcog""




****************************************************************
*TABLES
****************************************************************



//TABLE 1: DESCRIPIVE
use "${wd}temp${pspec}.dta", clear

tab informal [fw=fwgt]
tabstat hhsizer depratio female urban hhcsg hhoap hhcog hhremitrec hhremitsend [fw=fwgt], by(informal)
tabstat totwage [fw=fwgt], by(informal) stat(p25 p50 p75)

tab hhinformal [fw=fwgt]
tabstat hhsizer depratio female urban hhcsg hhoap hhcog hhremitrec hhremitsend [fw=fwgt], by(hhinformal)
tabstat hhincomepc [fw=fwgt], by(hhinformal) stat(p25 p50 p75)




//TABLE 2: TARGETING AND COVERAGE

use "${wd}temp${pspec}.dta", clear

//top up in each case
g topup_oap= hhnum_oap*$amtoap
g topup_csg= hhcsg_children*$amtcsg
g topup_cog= hhnum_cog*$amtcog
g topup_csgcog= hhnum_cog*$amtcog2 + hhcsg_children*$amtcsg2
g topup_oapcog= hhnum_cog*$amtcog2 + hhnum_oap*$amtoap2

//Convert to per capita
foreach var in oap csg cog csgcog oapcog {
	assert topup_`var'!=.
	g topuppc_`var'= topup_`var'/hhsizer
}

tab hhinformal [fw=fwgt]

*Coverage
tabstat all hhoap hhcsg hhcog hhcsgcog hhoapcog [fw=fwgt], s(sum)
tabstat all hhoap hhcsg hhcog hhcsgcog hhoapcog if hhinformal==1 [fw=fwgt], s(sum)


*Finance Targetting CSG
tabstat topuppc_oap topuppc_csg topuppc_cog topuppc_csgcog  topuppc_oapcog  [fw=fwgt], s(sum)
tabstat topuppc_oap topuppc_csg topuppc_cog topuppc_csgcog  topuppc_oapcog [fw=fwgt] if hhinformal==1, s(sum)





//TABLE 3: INFORMAL WORKERS
use "${wd}temp${pspec}.dta", clear

tab hhinfgrp if informal==1 [fw=fwgt]
tabstat hhsizer female urban hhremitrec hhremitsend  sa_id agecat* [fw=fwgt] if informal==1, by(hhinfgrp)
tabstat totwage [fw=fwgt] if informal==1, by(hhinfgrp) stat(p25 p50 p75)

tab hhinfgrp [fw=fwgt]
tabstat hhsizer female urban hhremitrec hhremitsend  sa_id agecat* [fw=fwgt], by(hhinfgrp)
tabstat hhincomepc [fw=fwgt], by(hhinfgrp) stat(p25 p50 p75)




//TABLE APPENDIX 1: INFORMAL WORKERS BY INDUSTRY

use "${wd}temp${pspec}.dta", clear

*Respectively: Primary occup, secondary occup, self emp, other self-emp, casual work
foreach var of varlist em1prod_c em2prod_c emssect emsothsect emcsect {
	assert inrange(`var', 0,10) | `var' < 0 | mi(`var') | `var' == 11
	assert `var' != 10 if inlist("`var'", "em1prod_c", "em2prod_c")
	replace `var' = 0 if `var' == 10	// recoding to make consistent
	replace `var' = . if `var' < 0 | `var' == 11
}
gen inf_sect = .
foreach var of varlist em1prod_c em2prod_c emssect emsothsect emcsect {
	replace inf_sect = `var' if mi(inf_sect) & informal == 1
}
lab val inf_sect w5_sec_code
*350,000 still missing. Seems ok.

g inf_indgrp= 1 if empltype==2 & informal==1
replace inf_indgrp= 2 if informal==1 & inf_indgrp==. & inf_sect==0
replace inf_indgrp= 3 if informal==1 & inf_indgrp==. & inf_sect==1
replace inf_indgrp= 4 if informal==1 & inf_indgrp==. & inf_sect==5
replace inf_indgrp= 5 if informal==1 & inf_indgrp==. & inf_sect==9
replace inf_indgrp= 6 if informal==1 & inf_indgrp==.
lab def inf_indgrp 1 "Self-emp" 2 "Private HH" 3 "Agriculture" 4 "Construction" 5 "CSP" 6 "Other"
lab val inf_indgrp  inf_indgrp 


tab inf_indgrp if informal==1 [fw=fwgt]
tabstat hhsizer female urban hhcsg hhoap hhcog hhremitrec hhremitsend  sa_id [fw=fwgt] if informal==1, by(inf_indgrp)
tabstat totwage [fw=fwgt] if informal==1, by(inf_indgrp) stat(p25 p50 p75)




//TABLE APPENDIX 2: INFORMAL WORKERS BY AGE PROFILE
use "${wd}temp${pspec}.dta", clear

tab age_cat if informal==1 [fw=fwgt]
tabstat hhsizer female urban hhcsg hhoap hhcog hhremitrec hhremitsend  depratio agedepratio sa_id [fw=fwgt] if informal==1, by(age_cat )
tabstat totwage [fw=fwgt] if informal==1, by(age_cat ) stat(p25 p50 p75)




//TABLE APPENDIX 3: INFORMAL WORKERS BY GRANT RECEIPT
use "${wd}temp${pspec}.dta", clear

* indiv receives CSG OR the other grant
gen csgcog = (csg == 1 | cog ==1)
gen oapcog = (oap == 1 | cog ==1)

* children younger than X (15)
gen child_15 = 1 if best_age_yrs <=14 & best_age_yrs >=0
bysort hhid: egen tot_child_15 = total(child_15)


foreach grp in all oap csg cog csgcog oapcog {
	di " "
	di " "
	di "group is `grp'"
	tab all [fw=fwgt] if `grp' == 1 
	tabstat hhsizer tot_child_15 female urban hhremitrec hhremitsend  depratio agedepratio sa_id hhinformal agecat* hhagecat* [fw=fwgt] if `grp' == 1
	tabstat hhincomepc [fw=fwgt] if `grp'==1, stat(p25 p50 p75)
}






****************************************************************
*VENN DIAGRAM BAR GRAPHS
****************************************************************


//Program to do venn diagram taking two groups as inputs
cap prog drop venndiag
program define venndiag
	syntax, var1name(string) display1name(string) var1col(string) var2name(string) display2name(string) var2col(string) 

	use "${wd}temp${pspec}.dta", clear

	g cat1_cat2= (`var1name'==1 & `var2name'==1)
	g cat1= (`var1name'==1 & `var2name'==0)
	g cat2= (`var1name'==0 & `var2name'==1)
	g neither= (`var1name'==0 & `var2name'==0)
	
	collapse (sum) cat1_cat2 cat1 cat2 neither [fw=fwgt], by(hhincomepc_decile)
	egen tot= rowtotal(cat1_cat2 cat1 cat2 neither)
	foreach var in cat1_cat2 cat1 cat2 neither {
		qui replace `var'= `var'/tot*100
	}
	
	graph bar (mean) cat1  cat1_cat2 cat2 neither, scheme(s1color) stack over(hhincomepc_decile, gap(200)) legend(on order(1 "`display1name'" 2 "Both `display1name'" "& `display2name'" 3 "`display2name'" 4 "Other") size(medsmall) col(4) region(lc(white)) symxsize(*.5) symysize(*.5)) b1title("Decile of household income per capita", size(medsmall)) ytitle("Individuals (%)", margin(small)) bar(1, color(`var1col'%70)) bar(2, color(green%70))  bar(3, color(`var2col'%70)) bar(4, color(gray%70)) /*note("Notes: Calculated using NIDS 2017 by Bassier, Budlender,  Zizzamia, Leibbrandt and Ranchhod", size(vsmall))*/ /* title("Overlap b/n `display1name' and `display2name' household members", size(medium)) */ blabel(bar, pos(center) format(%2.0f) size(small))
	
end

*Informal workers and OAP
venndiag, var1name(hhinformal) display1name(Informal-worker) var1col(navy) var2name(hhoap) display2name(OAP) var2col(gold) 
graph export "${figout}venndiag_infoap_main${pspec}.png", replace

*Informal workers and CSG
venndiag, var1name(hhinformal) display1name(Informal-worker) var1col(navy) var2name(hhcsg) display2name(CSG) var2col(red) 
graph export "${figout}venndiag_infcsg_main${pspec}.png", replace

*Informal workers and COG
venndiag, var1name(hhinformal) display1name(Informal-worker) var1col(navy) var2name(hhcog) display2name(CO-G) var2col(purple) 
graph export "${figout}venndiag_infcog_main${pspec}.png", replace

*Informal workers and CSG+COG
venndiag, var1name(hhinformal) display1name(Informal-worker) var1col(navy) var2name(hhcsgcog) display2name(CSG+COG) var2col(pink) 
graph export "${figout}venndiag_infcsgcog_main${pspec}.png", replace


*Informal workers and OAP+COG
venndiag, var1name(hhinformal) display1name(Informal-worker) var1col(navy) var2name(hhoapcog) display2name(OAP+COG) var2col(ltblue) 
graph export "${figout}venndiag_infoapcog_R&R${pspec}.png", replace

	
	
	
	
****************************************************************
*INCOME CHANGE
****************************************************************


//PCT CHANGE: INFORMAL-WORKER HOUSEHOLDS 
local loss=75
use "${wd}temp${pspec}.dta", clear



//Add amt to each hh, multiplied by recipients
g newhhincome_pre= hhincome
g newhhincome_no= hhincome - hhinformal_income*`loss'/100
	assignzero, incvar(newhhincome_no) limit(50)	
g newhhincome_oap= newhhincome_no + hhnum_oap*$amtoap
g newhhincome_csg= newhhincome_no + hhcsg_children*$amtcsg
g newhhincome_cog= newhhincome_no + hhnum_cog*$amtcog


//Define percentage income change for under each scenario: *per person* pct loss
g newhhincomepc_pre= newhhincome_pre/hhsizer
foreach var in no oap csg cog {
	assert newhhincome_`var'!=.
	g newhhincomepc_`var'= newhhincome_`var'/hhsizer
	g losspc_`var'= (newhhincomepc_`var' - newhhincomepc_pre)/newhhincomepc_pre * 100
}

collapse (mean) losspc_* if hhinformal==1 [fw=fwgt], by(hhincomepc_decile)

g nochange= 0
sort hhincomepc_decile

*Show for OAP, CSG, COG (leave out combinations)
twoway (scatter nochange hhincomepc_decile, connect(l) lc(gray*.5))(scatter losspc_no hhincomepc_decile, connect(l) lc(gray*.8)) (scatter losspc_oap hhincomepc_decile, connect(l) lc(gold)) (scatter losspc_csg hhincomepc_decile, connect(l) lc(red*.7))  (scatter losspc_cog hhincomepc_decile, connect(l) lc(purple*.7)), legend(rows(1) order(1 "Pre-Lockdown" 2 "Lockdown" "No intervention" 3 "Lockdown" "OAP+$amtoap" 4 "Lockdown" "CSG+$amtcsg" 5 "Lockdown" "COG $amtcog") region(lc(white)) pos(6) size(medsmall))  xtitle("Decile of per person household income", size(medsmall))  ytitle("Average change in income (%)", margin(medium)) /* ti("Pct. change in household income per capita for households w/ informal workers") subti("(`loss'% loss informal income)") */ yscale(range(-40 20)) ylabel(-40(10)20)

graph export "${figout}pctincomeloss_main${pspec}.png", replace

	
	
	
//INCOME TOP-UP: ALL HOUSEHOLDS
use "${wd}temp${pspec}.dta", clear


//top up in each case
g topup_oap= hhnum_oap*$amtoap
g topup_csg= hhcsg_children*$amtcsg
g topup_cog= hhnum_cog*$amtcog

//Convert to per capita
foreach var in oap csg cog {
	assert topup_`var'!=.
	g topuppc_`var'= topup_`var'/hhsizer
}



collapse (mean) topuppc_* [fw=fwgt], by(hhincomepc_decile)
sort hhincomepc_decile

twoway (scatter topuppc_oap hhincomepc_decile, connect(l) lc(gold)) (scatter topuppc_csg hhincomepc_decile, connect(l) lc(red*.7))  (scatter topuppc_cog hhincomepc_decile, connect(l) lc(purple*.7)), legend(rows(1) order(1 "OAP+$amtoap" 2 "CSG+$amtcsg" 3 "COG $amtcog") region(lc(white)) pos(6) size(medsmall))  xtitle("Decile of per person household income", size(medsmall)) ytitle("Average increase in income (Rands)", margin(medium)) /* ti("Pct. change in household income per capita for households w/ informal workers") subti("(`loss'% loss informal income)") */

graph export "${figout}levelincometopup_main${pspec}.png", replace




	
****************************************************************
*POVERTY IMPACT
****************************************************************

cap prog drop povstats
prog def povstats

	//Define poverty for each response: food line and upper bound
	foreach var in pre no oap csg cog csgcog oapcog {
		assert newhhincome_`var'!=.
		g fpl_`var'= (newhhincome_`var'/hhsizer`hhsize' < `fpl')
		g ubpl_`var'= (newhhincome_`var'/hhsizer`hhsize' < `ubpl')
		g gap_`var'= max((`ubpl' - newhhincome_`var'/hhsizer`hhsize')/`ubpl', 0)
		g gap2_`var'= gap_`var'^2
	}


	//Now compute for each variant in stata dta
	g intervention = ""
	g group= ""
	g povrate_fpl= .
	g povrate_ubpl= .
	g povrate_gap= .
	g povrate_gap2= .
	*Purely for coding: an index for the loop
	local j= 1
		
	*Loop: type of intervention (prelock, lock, lock + CSG, lock + CSG + COG)
	foreach interv in pre no oap csg cog csgcog oapcog {

		*all households
		di "starting interv `interv' for all households and j is `j'"

		qui replace intervention= "`interv'" if _n==`j'
		qui replace group= "all" if _n==`j'
		qui sum fpl_`interv' [aw=fwgt]
		qui replace povrate_fpl= r(mean)*100 if _n==`j'
		qui sum ubpl_`interv' [aw=fwgt]
		qui replace povrate_ubpl= r(mean)*100 if _n==`j'
		qui sum gap_`interv' [aw=fwgt]
		qui replace povrate_gap= r(mean)*100 if _n==`j'
		qui sum gap2_`interv' [aw=fwgt]
		qui replace povrate_gap2= r(mean)*100 if _n==`j'
		local j= `j'+1
		
		*hhinformal worker households 
		di "starting interv `interv' for informal households and j is `j'"
		
		qui replace intervention= "`interv'" if _n==`j'
		qui replace group= "hhinformal" if _n==`j'
		qui sum fpl_`interv' [aw=fwgt] if hhinformal==1
		qui replace povrate_fpl= r(mean)*100 if _n==`j'
		qui sum ubpl_`interv' [aw=fwgt] if hhinformal==1
		qui replace povrate_ubpl= r(mean)*100 if _n==`j'
		qui sum gap_`interv' [aw=fwgt] if hhinformal==1
		qui replace povrate_gap= r(mean)*100 if _n==`j'
		qui sum gap2_`interv' [aw=fwgt] if hhinformal==1
		qui replace povrate_gap2= r(mean)*100 if _n==`j'
		local j= `j'+1
		
	}


	*Keep just the summary stats
	drop if povrate_fpl==.
	keep intervention group povrate_fpl povrate_ubpl group povrate_gap povrate_gap2
	g povrate_ubpldiff= povrate_ubpl - povrate_fpl
	g povrate_gapdiff=  povrate_gap - povrate_gap2
	assert povrate_gapdiff >= 0 & povrate_ubpldiff >=0
	list

	*Order bars
	gen orderbar = 1 if intervention=="pre"
	replace orderbar = 2 if intervention=="no"
	replace orderbar = 3 if intervention=="oap"
	replace orderbar = 4 if intervention=="csg"
	replace orderbar = 5 if intervention=="cog"
	replace orderbar = 6 if intervention=="csgcog"
	replace orderbar = 7 if intervention=="oapcog"


	*Label All vs HHinformal
	g groupcat= 1 if group=="all"
	replace groupcat=2 if group== "hhinformal"
	lab def groupcat 1 "All households" 2 "Households w/ informal worker"
	lab val groupcat groupcat 


end
	
	
	
cap prog drop povfig
prog def povfig

syntax, [hhsize(string) losspct(integer 75)]

//Set locals
local fpl= 561*115.2/111.7
local ubpl= 1227*115.2/111.7
local loss= `losspct'


//Add amt to each hh, multiplied by recipients
use "${wd}temp${pspec}.dta", clear
g newhhincome_pre= hhincome
g newhhincome_no= hhincome - hhinformal_income*`loss'/100
	assignzero, incvar(newhhincome_no) limit(50)	// JBcheck
g newhhincome_oap= newhhincome_no + hhnum_oap*$amtoap
g newhhincome_csg= newhhincome_no + hhcsg_children*$amtcsg
g newhhincome_cog= newhhincome_no + hhnum_cog*$amtcog
g newhhincome_csgcog= newhhincome_no + hhcsg_children*$amtcsg2 + hhnum_cog*$amtcog2
g newhhincome_oapcog= newhhincome_no + hhnum_oap*$amtoap2 + hhnum_cog*$amtcog2


*Run numbers as programmed above
povstats

//HEADCOUNT
preserve
	gen pov1 = povrate_fpl
	gen pov2 = povrate_ubpldiff
	gen tempID = _n
	reshape long pov, i(tempID) j(povtype)
	egen outcomegrp =  group(orderbar povtype)
	separate pov, by(outcomegrp) gen(povsep)
	drop tempID 

	graph bar povsep*, ///
		over(orderbar, gap(30) relabel(1 "Pre-Lockdown" 2 "Lockdown" 3 "OAP+" 4 "CSG+" 5 "COG" 6 "COG & CSG+" 7 "COG & OAP+") label(labsize(small) angle(45) ))  ///
		over(groupcat, label(labsize(medsmall))) ///
		stack scheme(s1color)  ytitle("Headcount ratio (%)", size(medsmall) margin(small)) blabel(total, format(%2.1f) pos(top) size(vsmall)) ///
		bar(1, color(gray*.4)) bar(2, color(gray*.2)) ///
		bar(3, color(gray*.8)) bar(4, color(gray*.6)) ///
		bar(5, color(gold)) bar(6, color(gold*.5)) ///
		bar(7, color(red*.7)) bar(8, color(red*.35)) ///
		bar(9, color(purple*.7)) bar(10, color(purple*.35)) ///
		bar(11, color(pink*.7)) bar(12, color(pink*.35)) ///
		bar(13, color(ltblue*.7)) bar(14, color(ltblue*.35)) ///
		/* title("Poverty rates by lockdown scenario", size(medium)) subtitle("(`loss'% loss to informal income)", size(medsmall))	*/ ///
		legend(pos(11) ring(0) col(1) order(2 "Upper-bound poverty (lighter shade)" 1 "Food poverty (darker shade)" ) size(small)  symxsize(*.5) symysize(*.5))
	graph export "${figout}povertyloss_R&R`hhsize'`losspct'.png", replace
restore


//GAP
preserve
	gen pov1 = povrate_gap2
	gen pov2 = povrate_gapdiff
	gen tempID = _n
	reshape long pov, i(tempID) j(povtype)
	egen outcomegrp =  group(orderbar povtype)
	separate pov, by(outcomegrp) gen(povsep)
	drop tempID 

	graph bar povsep*, ///
		over(orderbar, gap(30) relabel(1 "Pre-Lockdown" 2 "Lockdown" 3 "OAP+" 4 "CSG+" 5 "COG" 6 "COG & CSG+" 7 "COG & OAP+") label(labsize(small) angle(45) ))  ///
		over(groupcat, label(labsize(medsmall))) ///
		stack scheme(s1color)  ytitle("Poverty outcome (%)", size(medsmall) margin(small)) blabel(total, format(%2.1f) pos(top) size(vsmall)) ///
		bar(1, color(gray*.4)) bar(2, color(gray*.2)) ///
		bar(3, color(gray*.8)) bar(4, color(gray*.6)) ///
		bar(5, color(gold)) bar(6, color(gold*.5)) ///
		bar(7, color(red*.7)) bar(8, color(red*.35)) ///
		bar(9, color(purple*.7)) bar(10, color(purple*.35)) ///
		bar(11, color(pink*.7)) bar(12, color(pink*.35)) ///
		bar(13, color(ltblue*.7)) bar(14, color(ltblue*.35)) ///
		/* title("Poverty rates by lockdown scenario", size(medium)) subtitle("(`loss'% loss to informal income)", size(medsmall)) */	 ///
		legend(pos(11) ring(0) col(1) order(2 "FGT1 (lighter shade)" 1 "FGT2 (darker shade)" ) size(small)  symxsize(*.5) symysize(*.5))
	graph export "${figout}povertyloss_gaps_R&R`hhsize'`losspct'.png", replace
restore
end


*MAIN
povfig


*EQUIVLENT SCALES
povfig, hhsize(equiv)



*NO SHARING
*Take away income from everyone. Only add back grant to direct recipient. Adjust for hhsizer here since divide later

local fpl= 561*115.2/111.7
local ubpl= 1227*115.2/111.7
local loss= 75

use "${wd}temp${pspec}.dta", clear

g newhhincome_pre= hhincome
g newhhincome_no= hhincome - hhinformal_income*`loss'/100
	assignzero, incvar(newhhincome_no) limit(50)	// JBcheck

g newhhincome_oap= newhhincome_no + hhsizer*oap*$amtoap
g newhhincome_csg= newhhincome_no + hhsizer*csg_children*$amtcsg
g newhhincome_cog= newhhincome_no + hhsizer*cog*$amtcog
g newhhincome_csgcog= newhhincome_no + hhsizer*csg_children*$amtcsg2 + hhsizer*cog*$amtcog2
g newhhincome_oapcog= newhhincome_no + hhsizer*oap*$amtoap2 + hhsizer*cog*$amtcog2


*Run same numbers as before
povstats


*HEADCOUNT
preserve
	gen pov1 = povrate_fpl
	gen pov2 = povrate_ubpldiff
	gen tempID = _n
	reshape long pov, i(tempID) j(povtype)
	egen outcomegrp =  group(orderbar povtype)
	separate pov, by(outcomegrp) gen(povsep)
	drop tempID 

	graph bar povsep*, ///
		over(orderbar, gap(30) relabel(1 "Pre-Lockdown" 2 "Lockdown" 3 "OAP+" 4 "CSG+" 5 "COG" 6 "COG & CSG+" 7 "COG & OAP+") label(labsize(small) angle(45) ))  ///
		over(groupcat, label(labsize(medsmall))) ///
		stack scheme(s1color)  ytitle("Headcount ratio (%)", size(medsmall) margin(small)) blabel(total, format(%2.1f) pos(top) size(vsmall)) ///
		bar(1, color(gray*.4)) bar(2, color(gray*.2)) ///
		bar(3, color(gray*.8)) bar(4, color(gray*.6)) ///
		bar(5, color(gold)) bar(6, color(gold*.5)) ///
		bar(7, color(red*.7)) bar(8, color(red*.35)) ///
		bar(9, color(purple*.7)) bar(10, color(purple*.35)) ///
		bar(11, color(pink*.7)) bar(12, color(pink*.35)) ///
		bar(13, color(ltblue*.7)) bar(14, color(ltblue*.35)) ///
		/* title("Poverty rates by lockdown scenario", size(medium)) subtitle("(`loss'% loss to informal income)", size(medsmall))	*/ ///
		legend(pos(11) ring(0) col(1) order(2 "Upper-bound poverty (lighter shade)" 1 "Food poverty (darker shade)" ) size(small)  symxsize(*.5) symysize(*.5))
	graph export "${figout}povertyloss_R&Rnoshare.png", replace
restore


*GAP
preserve
	gen pov1 = povrate_gap2
	gen pov2 = povrate_gapdiff
	gen tempID = _n
	reshape long pov, i(tempID) j(povtype)
	egen outcomegrp =  group(orderbar povtype)
	separate pov, by(outcomegrp) gen(povsep)
	drop tempID 

	graph bar povsep*, ///
		over(orderbar, gap(30) relabel(1 "Pre-Lockdown" 2 "Lockdown" 3 "OAP+" 4 "CSG+" 5 "COG" 6 "COG & CSG+" 7 "COG & OAP+") label(labsize(small) angle(45) ))  ///
		over(groupcat, label(labsize(medsmall))) ///
		stack scheme(s1color)  ytitle("Poverty outcome (%)", size(medsmall) margin(small)) blabel(total, format(%2.1f) pos(top) size(vsmall)) ///
		bar(1, color(gray*.4)) bar(2, color(gray*.2)) ///
		bar(3, color(gray*.8)) bar(4, color(gray*.6)) ///
		bar(5, color(gold)) bar(6, color(gold*.5)) ///
		bar(7, color(red*.7)) bar(8, color(red*.35)) ///
		bar(9, color(purple*.7)) bar(10, color(purple*.35)) ///
		bar(11, color(pink*.7)) bar(12, color(pink*.35)) ///
		bar(13, color(ltblue*.7)) bar(14, color(ltblue*.35)) ///
		/* title("Poverty rates by lockdown scenario", size(medium)) subtitle("(`loss'% loss to informal income)", size(medsmall)) */	 ///
		legend(pos(11) ring(0) col(1) order(2 "FGT1 (lighter shade)" 1 "FGT2 (darker shade)" ) size(small)  symxsize(*.5) symysize(*.5))
	graph export "${figout}povertyloss_gaps_R&Rnoshare.png", replace
restore

	

****************************************************************
*INCOME SOURCE BY DECILE
****************************************************************


*Graph twoway area
use "${wd}temp${pspec}.dta", clear

collapse (sum) hhwage hhinvest hhremitt hhgovt hhother hhagric hhincome [fw=fwgt], by(hhincomepc_decile hhinformal)

foreach var in hhwage hhinvest hhremitt hhgovt hhother hhagric hhincome {
	bys hhincomepc_decile (hhinformal): replace `var'= `var'[1]+`var'[2] if _n==1
}

g other= hhother + hhagric 
g hhtotinc= (hhwage+hhinvest+hhremitt+hhgovt+other)

foreach var in hhwage hhinvest hhremitt hhgovt other {
	replace `var'= 100*`var'/hhtotinc
}

lab def hhinformal 0 "All HH members" 1 "Informal-worker HH members"
lab val hhinformal hhinformal

graph bar hhwage hhgovt hhremitt hhinvest other, over(hhincomepc_decile) asyvar stack over(hhinformal, label(labsize(small))) bar(1, color(maroon*.7)) bar(2, color(green*.7)) bar(3, color(navy*.7)) bar(4, color(gold*.7)) bar(5, color(gray*.7)) legend(pos(6) row(1) order(1 "Labour market" 2 "Grants" 3 "Remittances" 4 "Investments" 5 "Other")) b1title("Household income per capita decile") ytitle("Proportion of income (%)")

graph export "${figout}incomesources${pspec}.png", replace




****************************************************************
*END MAIN ANALYSIS
****************************************************************




