
//COVID ANALYSIS: ANALYSIS FILE FOR HOUSEHOLD COMPOSITION

/*
THIS FILE CONTAINS
1. INFORMAL WORKER DECOMPOSITION of POVERTY IMPACT
2. INCOME CHANGE (EQUIV)
3. VENN DIAG (EQUIV)
4. POVERTY EFFECT UNDER NO SHARING, BY GENDER
5. OPTIMALITY BAR GRAH
*/


clear all
set varabbrev off
set more off, permanent
set scheme plotplain	

if c(username)=="Rocco Zizzamia" {
 cd "C:\Users\Rocco Zizzamia\Dropbox\Policy_response_corona\"
}
if c(username)=="ihsaa" {
	cd "C:\Users\ihsaa\Dropbox\Policy_response_corona\"
}
if c(username)=="joshb" {
 cd "C:\Users\joshb\Dropbox\projects\Policy_response_corona\"
}


global wd "WDpaper_analysis\"
global figout "${wd}rawfigs\"


****************************************************************
*PRELIMINARIES
****************************************************************

cap program drop assignzero
program define assignzero
	syntax, incvar(varname) limit(integer)
	qui count if `incvar' < 0
	if r(N) > `limit' {
		di "{err}more than `limit' negative values in `incvar'"
		exit 498
	}
	else {
		replace `incvar' = 0 if `incvar' < 0
	}
end




********************************************************************************
*POVERTY GRAPH FOR SUBGROUPS
********************************************************************************


//Set locals
local fpl= 561*115.2/111.7
local ubpl= 1227*115.2/111.7
local loss= 75

//Add amt to each hh, multiplied by recipients
use "${wd}temp${pspec}.dta", clear
g newhhincome_pre= hhincome
g newhhincome_no= hhincome - hhinformal_income*`loss'/100
	assignzero, incvar(newhhincome_no) limit(50)	// JBcheck
g newhhincome_oap= newhhincome_no + hhnum_oap*$amtoap
g newhhincome_csg= newhhincome_no + hhcsg_children*$amtcsg
g newhhincome_cog= newhhincome_no + hhnum_cog*$amtcog
g newhhincome_csgcog= newhhincome_no + hhcsg_children*$amtcsg2 + hhnum_cog*$amtcog2


//Define poverty for each response: food line and upper bound
foreach var in pre no oap csg cog csgcog {
	assert newhhincome_`var'!=.
	g fpl_`var'= (newhhincome_`var'/hhsizer < `fpl')
	g ubpl_`var'= (newhhincome_`var'/hhsizer < `ubpl')
	g gap_`var'= max((`ubpl' - newhhincome_`var'/hhsizer)/`ubpl', 0)
	g gap2_`var'= gap_`var'^2
}


//Now compute for each variant in stata dta
g intervention = ""
g group= .
g povrate_fpl= .
g povrate_ubpl= .
g povrate_gap= .
g povrate_gap2= .
*Purely for coding: an index for the loop
local j= 1
	
*Loop: type of intervention (prelock, lock, lock + CSG, lock + CSG + COG)
foreach interv in pre no oap csg cog csgcog {
	forval i=1/3 {
		di "starting interv `interv' for group `i' and j is `j'"
		qui replace intervention= "`interv'" if _n==`j'
		qui replace group= `i' if _n==`j'
		qui sum fpl_`interv' [aw=fwgt] if hhinfgrp ==`i'
		qui replace povrate_fpl= r(mean)*100 if _n==`j'
		qui sum ubpl_`interv' [aw=fwgt] if hhinfgrp ==`i'
		qui replace povrate_ubpl= r(mean)*100 if _n==`j'
		
		qui sum gap_`interv' [aw=fwgt] if hhinfgrp ==`i'
		qui replace povrate_gap= r(mean)*100 if _n==`j'
		qui sum gap2_`interv' [aw=fwgt] if hhinfgrp ==`i'
		qui replace povrate_gap2= r(mean)*100 if _n==`j'
		
		local j= `j'+1
	}
}


drop if povrate_fpl==.
keep intervention group povrate_fpl povrate_ubpl povrate_gap povrate_gap2
g povrate_ubpldiff= povrate_ubpl - povrate_fpl
g povrate_gapdiff= povrate_gap - povrate_gap2
assert povrate_gapdiff > 0
list

gen orderbar = 1 if intervention=="pre"
replace orderbar = 2 if intervention=="no"
replace orderbar = 3 if intervention=="oap"
replace orderbar = 4 if intervention=="csg"
replace orderbar = 5 if intervention=="cog"
replace orderbar = 6 if intervention=="csgcog"

lab val group hhinfgrp


// HEADCOUNT
preserve

	* Seperate	// JBcheck
	gen pov1 = povrate_fpl
	gen pov2 = povrate_ubpldiff
	gen tempID = _n
	reshape long pov, i(tempID) j(povtype)
	egen outcomegrp =  group(orderbar povtype)
	separate pov, by(outcomegrp) gen(povsep)
	drop tempID 

	graph bar povsep*, ///
		over(orderbar, /*gap(30)*/ relabel(1 "Pre-Lockdown" 2 "Lockdown" 3 "OAP+" 4 "CSG+" 5 "COG" 6 "COG & CSG+") label(labsize(small) angle(45) ))  ///
		over(group, relabel(1 "Formal co-resident" 2 `" "Grant &" "no formal co-resident" "' 3 `" "No grant &" "no formal co-resident" "') label(labsize(medsmall))) ///
		stack scheme(s1color)  ytitle("Headcount ratio (%)", size(medsmall) margin(small)) blabel(total, format(%2.1f) pos(top) size(vsmall)) ///
		bar(1, color(gray*.4)) bar(2, color(gray*.2)) ///
		bar(3, color(gray*.8)) bar(4, color(gray*.6)) ///
		bar(5, color(gold)) bar(6, color(gold*.5)) ///
		bar(7, color(red*.7)) bar(8, color(red*.35)) ///
		bar(9, color(purple*.7)) bar(10, color(purple*.35)) ///
		bar(11, color(pink*.7)) bar(12, color(pink*.35)) ///
		/* title("Poverty rates by lockdown scenario", size(medium)) subtitle("(`loss'% loss to informal income)", size(medsmall))	*/ ///
		legend(pos(11) ring(0) col(1) order(2 "Upper-bound poverty (lighter shade)" 1 "Food poverty (darker shade)" ) size(vsmall)  symxsize(*.5) symysize(*.5)) ///
		yscale(range(0 65))
	graph export "${figout}povertyloss_byinfgrp_headcount${pspec}.png", replace	

restore




// Gaps
preserve

	* Seperate	// JBcheck
	gen pov1 = povrate_gap2
	gen pov2 = povrate_gapdiff
	gen tempID = _n
	reshape long pov, i(tempID) j(povtype)
	egen outcomegrp =  group(orderbar povtype)
	separate pov, by(outcomegrp) gen(povsep)
	drop tempID 

	graph bar povsep*, ///
		over(orderbar, /*gap(30)*/ relabel(1 "Pre-Lockdown" 2 "Lockdown" 3 "OAP+" 4 "CSG+" 5 "COG" 6 "COG & CSG+") label(labsize(small) angle(45) ))  ///
		over(group, relabel(1 "Formal co-resident" 2 `" "Grant &" "no formal co-resident" "' 3 `" "No grant &" "no formal co-resident" "') label(labsize(medsmall))) ///
		stack scheme(s1color)  ytitle("Poverty outcome (%)", size(medsmall) margin(small)) blabel(total, format(%2.1f) pos(top) size(vsmall)) ///
		bar(1, color(gray*.4)) bar(2, color(gray*.2)) ///
		bar(3, color(gray*.8)) bar(4, color(gray*.6)) ///
		bar(5, color(gold)) bar(6, color(gold*.5)) ///
		bar(7, color(red*.7)) bar(8, color(red*.35)) ///
		bar(9, color(purple*.7)) bar(10, color(purple*.35)) ///
		bar(11, color(pink*.7)) bar(12, color(pink*.35)) ///
		/* title("Poverty rates by lockdown scenario", size(medium)) subtitle("(`loss'% loss to informal income)", size(medsmall))	*/ ///
		legend(pos(11) ring(0) col(1) order(2 "FGT1 (lighter shade)" 1 "FGT2 (darker shade)") size(vsmall)  symxsize(*.5) symysize(*.5)) ///
		yscale(range(0 44))
	graph export "${figout}povertyloss_byinfgrp_gaps${pspec}.png", replace	

restore
	

	
	

//FREQ BY GROUP INFORMAL WORKER

use "${wd}temp${pspec}.dta", clear
tab hhinfgrp if hhinformal==1, gen(hhinfgrp)
tab hhinfgrp if informal==1, gen(infgrp)
collapse (sum) hhinfgrp1 hhinfgrp2 hhinfgrp3 infgrp1 infgrp2 infgrp3 [fw=fwgt], by(hhincomepc_decile)
forval i=1/3 {
	replace hhinfgrp`i'= hhinfgrp`i'/1e6 
	replace infgrp`i'= infgrp`i'/1e6
}

graph bar (sum) infgrp1 infgrp2 infgrp3, scheme(s1color) stack over(hhincomepc_decile, gap(200))  legend(on order(1 "Formal worker" 2 "Grant recipient" 3 "Neither") size(medsmall) col(3) region(lc(white)) symxsize(*.5) symysize(*.5))  blabel(bar, pos(center) format(%3.2f) size(vsmall)) b1title("National deciles of household income per capita", size(medium)) ytitle("Informal workers (millions)", margin(medium) size(medsmall)) bar(1, color(ltblue))  bar(2, color(green*.5))  bar(3, color(red*.5)) 
graph export "${figout}venndiag_byinfgrp_informal${pspec}.png", replace	

graph bar (sum) hhinfgrp1 hhinfgrp2 hhinfgrp3, scheme(s1color) stack over(hhincomepc_decile, gap(200))  legend(on order(1 "Formal worker" 2 "Grant recipient" 3 "Neither") size(medsmall) col(3) region(lc(white)) symxsize(*.5) symysize(*.5))  blabel(bar, pos(center) format(%2.1f) size(small)) b1title("National deciles of household income per capita", size(medium)) ytitle("Informal-worker household members (millions)", margin(medium) size(medsmall)) bar(1, color(ltblue))  bar(2, color(green*.5))  bar(3, color(red*.5))
graph export "${figout}venndiag_byinfgrp_hhinformal${pspec}.png", replace	





	
	
****************************************************************
*INCOME CHANGE
****************************************************************


//PCT CHANGE: INFORMAL-WORKER HOUSEHOLDS 
local loss=75
use "${wd}temp.dta", clear


//Add amt to each hh, multiplied by recipients
g newhhincome_pre= hhincome
g newhhincome_no= hhincome - hhinformal_income*`loss'/100
	assignzero, incvar(newhhincome_no) limit(50)	// JBcheck
g newhhincome_oap= newhhincome_no + hhnum_oap*$amtoap
g newhhincome_csg= newhhincome_no + hhcsg_children*$amtcsg
g newhhincome_cog= newhhincome_no + hhnum_cog*$amtcog


//Define percentage income change for under each scenario: *per person* pct loss
g newhhincomepc_pre= newhhincome_pre/hhsizerequiv
foreach var in no oap csg cog {
	assert newhhincome_`var'!=.
	g newhhincomepc_`var'= newhhincome_`var'/hhsizerequiv
	g losspc_`var'= (newhhincomepc_`var' - newhhincomepc_pre)/newhhincomepc_pre * 100
}

collapse (mean) losspc_* if hhinformal==1 [fw=fwgt], by(hhincomeequiv_decile)

g nochange= 0
sort hhincomeequiv_decile

*Only CSG 
twoway (scatter nochange hhincomeequiv_decile, connect(l) lc(gray*.5))(scatter losspc_no hhincomeequiv_decile, connect(l) lc(gray*.8)) (scatter losspc_oap hhincomeequiv_decile, connect(l) lc(gold)) (scatter losspc_csg hhincomeequiv_decile, connect(l) lc(red*.7))  (scatter losspc_cog hhincomeequiv_decile, connect(l) lc(purple*.7)) , legend(rows(1) order(1 "Pre-Lockdown" 2 "Lockdown" "No intervention" 3 "Lockdown" "OAP+$amtoap" 4 "Lockdown" "CSG+$amtcsg" 5 "Lockdown" "COG $amtcog") region(lc(white)) pos(6))  xtitle("Decile of household income (equivalence scale)")  ytitle("Ave change in income (%)", margin(medium)) /* ti("Pct. change in household income for informal-worker HHs using equivalence scale") subti("(`loss'% loss informal income)") */ yscale(range(-50 10)) ylabel(-50(10)10) 

graph export "${figout}pctincomeloss_equiv.png", replace

	
	
	
	
//INCOME TOP-UP: ALL HOUSEHOLDS
use "${wd}temp.dta", clear


//top up in each case
g topup_oap= hhnum_oap*$amtoap
g topup_csg= hhcsg_children*$amtcsg
g topup_cog= hhnum_cog*$amtcog


//Convert to per capita
foreach var in oap csg cog {
	assert topup_`var'!=.
	g topuppc_`var'= topup_`var'/hhsizerequiv
}

	
graph bar (mean) topuppc_oap topuppc_csg topuppc_cog [fw=fwgt], scheme(s1color) over(hhincomeequiv_decile, gap(200)) bar(1, color(gold)) bar(2, color(red*.7)) bar(3, color(purple*.7))  legend(rows(1) order(1 "OAP+$amtoap" 2 "CSG+$amtcsg" 3 "COG $amtcog" 4 "CSG+$amtcsg2, COG $amtcog2") size(vsmall) region(lc(white)) symxsize(*.5) symysize(*.5))  b1title("Decile of household income (equivalence scale)", size(small)) ytitle("Amount from grant increases (Rands)", margin(large)) /* title("Average increase in income per person", size(medium)) */ blabel(total, format(%2.0f) size(vsmall))
	
graph export "${figout}levelincometopup_equiv.png", replace





****************************************************************
*VENN DIAGRAM BAR GRAPHS
****************************************************************


cap prog drop venndiag_equiv
program define venndiag_equiv
	syntax, var1name(string) display1name(string) var1col(string) var2name(string) display2name(string) var2col(string) 

	use "${wd}temp.dta", clear
	g equivwgt= (hhsizerequiv/hhsizer)*fwgt

	g cat1_cat2= (`var1name'==1 & `var2name'==1)
	g cat1= (`var1name'==1 & `var2name'==0)
	g cat2= (`var1name'==0 & `var2name'==1)
	g neither= (`var1name'==0 & `var2name'==0)
	
	collapse (sum) cat1_cat2 cat1 cat2 neither [fw=fwgt], by(hhincomeequiv_decile)
	egen tot= rowtotal(cat1_cat2 cat1 cat2 neither)
	foreach var in cat1_cat2 cat1 cat2 neither {
		qui replace `var'= `var'/tot*100
	}
	graph bar (mean) cat1  cat1_cat2 cat2 neither, scheme(s1color) stack over(hhincomeequiv_decile, gap(200)) legend(on order(1 "`display1name'" 2 "Both `display1name'" "& `display2name'" 3 "`display2name'" 4 "Other") size(medsmall) col(4) region(lc(white)) symxsize(*.5) symysize(*.5)) b1title("Decile of household income (equivalence scale)", size(medsmall)) ytitle("Individuals (%)", margin(small)) bar(1, color(`var1col'%70)) bar(2, color(green%70))  bar(3, color(`var2col'%70)) bar(4, color(gray%70)) /* title("Overlap b/n `display1name' and `display2name' household members", size(medium)) */ blabel(bar, pos(center) format(%2.0f) size(small))
	
end

venndiag_equiv, var1name(hhinformal) display1name(Informal-worker) var1col(navy) var2name(hhoap) display2name(OAP) var2col(gold) 
graph export "${figout}venndiag_infoap_equiv.png", replace

venndiag_equiv, var1name(hhinformal) display1name(Informal-worker) var1col(navy) var2name(hhcsg) display2name(CSG) var2col(red) 
graph export "${figout}venndiag_infcsg_equiv.png", replace

venndiag_equiv, var1name(hhinformal) display1name(Informal-worker) var1col(navy) var2name(hhcog) display2name(CO-G) var2col(purple) 
graph export "${figout}venndiag_infcog_equiv.png", replace

venndiag_equiv, var1name(hhinformal) display1name(Informal-worker) var1col(navy) var2name(hhcsgcog) display2name(CSG+COG) var2col(pink) 
graph export "${figout}venndiag_infcsgcog_equiv.png", replace



********************************************************************************
*POVERTY NO HH SHARING OF NEW GRANTS BY GENDER
********************************************************************************


//Set locals
local fpl= 561*115.2/111.7
local ubpl= 1227*115.2/111.7
local loss= 75


//CHANGE FROM NORMAL HOUSEHOLD INCOME CALCULATION:
*Take away income from everyone
*Only add back grant to direct recipient
*Adjust for hhsizer here since divide later

use "${wd}temp${pspec}.dta", clear

g newhhincome_pre= hhincome
g newhhincome_no= hhincome - hhinformal_income*`loss'/100
	assignzero, incvar(newhhincome_no) limit(50)	// JBcheck

g newhhincome_oap= newhhincome_no + hhsizer*oap*$amtoap
g newhhincome_csg= newhhincome_no + hhsizer*csg_children*$amtcsg
g newhhincome_cog= newhhincome_no + hhsizer*cog*$amtcog
g newhhincome_csgcog= newhhincome_no + hhsizer*csg_children*$amtcsg2 + hhsizer*cog*$amtcog2
g newhhincome_oapcog= newhhincome_no + hhsizer*oap*$amtoap2 + hhsizer*cog*$amtcog2

//Define poverty for each response: food line and upper bound
foreach var in pre no oap csg cog csgcog oapcog {
	assert newhhincome_`var'!=.
	g fpl_`var'= (newhhincome_`var'/hhsizer`hhsize' < `fpl')
	g ubpl_`var'= (newhhincome_`var'/hhsizer`hhsize' < `ubpl')
	g gap_`var'= max((`ubpl' - newhhincome_`var'/hhsizer`hhsize')/`ubpl', 0)
	g gap2_`var'= gap_`var'^2
}


//Now compute for each variant in stata dta
g intervention = ""
g group= ""
g povrate_gap= .
g povrate_gap2= .
g women= .

*Purely for coding: an index for the loop
local j= 1
	
*Loop: type of intervention (prelock, lock, lock + CSG, lock + CSG + COG)
foreach interv in pre no oap csg cog csgcog oapcog {
	
	forval i= 0 / 1 {
	
	*all households
	di "starting interv `interv' for all households and j is `j'"

	replace women= `i' if _n==`j'
	qui replace intervention= "`interv'" if _n==`j'
	qui replace group= "all" if _n==`j'

	qui sum gap_`interv' [aw=fwgt] if female==`i'
	qui replace povrate_gap= r(mean)*100 if _n==`j'
	qui sum gap2_`interv' [aw=fwgt] if female==`i'
	qui replace povrate_gap2= r(mean)*100 if _n==`j'
	local j= `j'+1
	
	*hhinformal worker households 
	di "starting interv `interv' for informal households and j is `j'"
	
	replace women= `i' if _n==`j'
	qui replace intervention= "`interv'" if _n==`j'
	qui replace group= "hhinformal" if _n==`j'

	qui sum gap_`interv' [aw=fwgt] if hhinformal==1 & female==`i'
	qui replace povrate_gap= r(mean)*100 if _n==`j'
	qui sum gap2_`interv' [aw=fwgt] if hhinformal==1 & female==`i'
	qui replace povrate_gap2= r(mean)*100 if _n==`j'
	local j= `j'+1
	
	}
	
}


*Keep just the summary stats
drop if povrate_gap==.
keep intervention group group povrate_gap povrate_gap2 women 
g povrate_gapdiff=  povrate_gap - povrate_gap2
assert povrate_gapdiff >= 0
list

*Order bars
gen orderbar = 1 if intervention=="pre"
replace orderbar = 2 if intervention=="no"
replace orderbar = 3 if intervention=="oap"
replace orderbar = 4 if intervention=="csg"
replace orderbar = 5 if intervention=="cog"
replace orderbar = 6 if intervention=="csgcog"
replace orderbar = 7 if intervention=="oapcog"


*Label All vs HHinformal
g groupcat= 1 if group=="all"
replace groupcat=2 if group== "hhinformal"
lab def groupcat 1 "All households" 2 "Households w/ informal worker"
lab val groupcat groupcat 


//GAP
forval i= 0 / 1 {
preserve
	* seperate // JBcheck
	keep if women==`i'
	gen pov1 = povrate_gap2
	gen pov2 = povrate_gapdiff
	gen tempID = _n
	reshape long pov, i(tempID) j(povtype)
	egen outcomegrp =  group(orderbar povtype)
	separate pov, by(outcomegrp) gen(povsep)
	drop tempID 

	graph bar povsep*, ///
		over(orderbar, gap(30) relabel(1 "Pre-Lockdown" 2 "Lockdown" 3 "OAP+" 4 "CSG+" 5 "COG" 6 "COG & CSG+" 7 "COG & OAP+") label(labsize(small) angle(45) ))  ///
		over(groupcat, label(labsize(medsmall))) ///
		stack scheme(s1color)  ytitle("Poverty outcome (%)", size(medsmall) margin(small)) blabel(total, format(%2.1f) pos(top) size(vsmall)) ///
		bar(1, color(gray*.4)) bar(2, color(gray*.2)) ///
		bar(3, color(gray*.8)) bar(4, color(gray*.6)) ///
		bar(5, color(gold)) bar(6, color(gold*.5)) ///
		bar(7, color(red*.7)) bar(8, color(red*.35)) ///
		bar(9, color(purple*.7)) bar(10, color(purple*.35)) ///
		bar(11, color(pink*.7)) bar(12, color(pink*.35)) ///
		bar(13, color(ltblue*.7)) bar(14, color(ltblue*.35)) ///
		/* title("Poverty rates by lockdown scenario", size(medium)) subtitle("(`loss'% loss to informal income)", size(medsmall)) */	 ///
		legend(pos(11) ring(0) col(1) order(2 "FGT1 (lighter shade)" 1 "FGT2 (darker shade)" ) size(small)  symxsize(*.5) symysize(*.5))
	graph export "${figout}povertyloss_gaps_R&Rnoshare_fem`i'.png", replace
restore
}



	
********************************************************************************
*OPTIMALITY CODING
********************************************************************************

//OPTIMAL ALLOCATION BY BUDGET

//Load data from R (see R script)
use "${wd}budgets_optima.dta", clear
replace budget= budget/1e9

//Plot
twoway (scatter csgamt budget, connect(l) lc(red*.7))(scatter cogamt budget, connect(l) lc(purple*.7))(bar povgap budget, barw(.5) fcolor(gray%.5) yaxis(2)), legend(rows(1) order(1 "CSG value" 2 "COG value" 3 "Poverty gap (FGT1)") region(lc(white)) pos(6) size(medsmall))  xtitle("Total budget allocation (R'billion)", size(medsmall))  ytitle("Optimal grant values (Rands)", margin(medium) axis(1)) ytitle("Corresponding poverty gap (%)", margin(medium) axis(2))

graph export "${figout}optima_budget.png", replace


//OPTIMAL ALLOCATION BY WEIGHTING

//Load data from R (see R script)
use "${wd}noninfwgt_optima.dta", clear


//Plot
twoway (scatter csgamt noninfwgt, connect(l) lc(red*.7))(scatter cogamt noninfwgt, connect(l) lc(purple*.7)), legend(rows(1) order(1 "CSG value" 2 "COG value") region(lc(white)) pos(6) size(medsmall))  xtitle("Weighting on non-informal worker household members", size(medsmall))  ytitle("Optimal grant values (Rands)", margin(medium) axis(1)) 

graph export "${figout}optima_noninfwgt.png", replace

	

********************************************************************************
*END HH COMPOSITION
********************************************************************************

